Class: Aws::QConnect::Types::AppIntegrationsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::AppIntegrationsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Configuration information for Amazon AppIntegrations to automatically ingest content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_integration_arn ⇒ String
The Amazon Resource Name (ARN) of the AppIntegrations DataIntegration to use for ingesting content.
-
#object_fields ⇒ Array<String>
The fields from the source that are made available to your agents in Amazon Q in Connect.
Instance Attribute Details
#app_integration_arn ⇒ String
The Amazon Resource Name (ARN) of the AppIntegrations DataIntegration to use for ingesting content.
-
For Salesforce, your AppIntegrations DataIntegration must have an ObjectConfiguration if objectFields is not provided, including at least
Id,ArticleNumber,VersionNumber,Title,PublishStatus, andIsDeletedas source fields. -
For ServiceNow, your AppIntegrations DataIntegration must have an ObjectConfiguration if objectFields is not provided, including at least
number,short_description,sys_mod_count,workflow_state, andactiveas source fields. -
For Zendesk, your AppIntegrations DataIntegration must have an ObjectConfiguration if
objectFieldsis not provided, including at leastid,title,updated_at, anddraftas source fields. -
For SharePoint, your AppIntegrations DataIntegration must have a FileConfiguration, including only file extensions that are among
docx,pdf,html,htm, andtxt. -
For Amazon S3, the ObjectConfiguration and FileConfiguration of your AppIntegrations DataIntegration must be null. The
SourceURIof your DataIntegration must use the following format:s3://your_s3_bucket_name.The bucket policy of the corresponding S3 bucket must allow the Amazon Web Services principal
app-integrations.amazonaws.comto performs3:ListBucket,s3:GetObject, ands3:GetBucketLocationagainst the bucket.
1110 1111 1112 1113 1114 1115 |
# File 'lib/aws-sdk-qconnect/types.rb', line 1110 class AppIntegrationsConfiguration < Struct.new( :app_integration_arn, :object_fields) SENSITIVE = [] include Aws::Structure end |
#object_fields ⇒ Array<String>
The fields from the source that are made available to your agents in Amazon Q in Connect. Optional if ObjectConfiguration is included in the provided DataIntegration.
-
For Salesforce, you must include at least
Id,ArticleNumber,VersionNumber,Title,PublishStatus, andIsDeleted. -
For ServiceNow, you must include at least
number,short_description,sys_mod_count,workflow_state, andactive. -
For Zendesk, you must include at least
id,title,updated_at, anddraft.
Make sure to include additional fields. These fields are indexed and used to source recommendations.
1110 1111 1112 1113 1114 1115 |
# File 'lib/aws-sdk-qconnect/types.rb', line 1110 class AppIntegrationsConfiguration < Struct.new( :app_integration_arn, :object_fields) SENSITIVE = [] include Aws::Structure end |