Class: Aws::QConnect::Types::DeleteAIPromptVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::DeleteAIPromptVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_prompt_id ⇒ String
The identifier of the Amazon Q in Connect AI prompt.
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#version_number ⇒ Integer
The version number of the AI Prompt version to be deleted.
Instance Attribute Details
#ai_prompt_id ⇒ String
The identifier of the Amazon Q in Connect AI prompt.
4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-qconnect/types.rb', line 4004 class DeleteAIPromptVersionRequest < Struct.new( :assistant_id, :ai_prompt_id, :version_number) SENSITIVE = [] include Aws::Structure end |
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-qconnect/types.rb', line 4004 class DeleteAIPromptVersionRequest < Struct.new( :assistant_id, :ai_prompt_id, :version_number) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version number of the AI Prompt version to be deleted.
4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-qconnect/types.rb', line 4004 class DeleteAIPromptVersionRequest < Struct.new( :assistant_id, :ai_prompt_id, :version_number) SENSITIVE = [] include Aws::Structure end |