Class: Aws::QConnect::Types::DeleteImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::DeleteImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#import_job_id ⇒ String
The identifier of the import job to be deleted.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
Instance Attribute Details
#import_job_id ⇒ String
The identifier of the import job to be deleted.
4116 4117 4118 4119 4120 4121 |
# File 'lib/aws-sdk-qconnect/types.rb', line 4116 class DeleteImportJobRequest < Struct.new( :knowledge_base_id, :import_job_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
4116 4117 4118 4119 4120 4121 |
# File 'lib/aws-sdk-qconnect/types.rb', line 4116 class DeleteImportJobRequest < Struct.new( :knowledge_base_id, :import_job_id) SENSITIVE = [] include Aws::Structure end |