Class: Aws::QConnect::Types::GetImportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::GetImportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#import_job_id ⇒ String
The identifier of the import job to retrieve.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base that the import job belongs to.
Instance Attribute Details
#import_job_id ⇒ String
The identifier of the import job to retrieve.
5103 5104 5105 5106 5107 5108 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5103 class GetImportJobRequest < Struct.new( :import_job_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base that the import job belongs to.
5103 5104 5105 5106 5107 5108 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5103 class GetImportJobRequest < Struct.new( :import_job_id, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |