Class: Aws::QConnect::Types::ImportJobData
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ImportJobData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Summary information about the import job.
Constant Summary collapse
- SENSITIVE =
[:url, :failed_record_report]
Instance Attribute Summary collapse
-
#created_time ⇒ Time
The timestamp when the import job was created.
-
#external_source_configuration ⇒ Types::ExternalSourceConfiguration
The configuration information of the external data source.
-
#failed_record_report ⇒ String
The link to download the information of resource data that failed to be imported.
-
#import_job_id ⇒ String
The identifier of the import job.
-
#import_job_type ⇒ String
The type of the import job.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#last_modified_time ⇒ Time
The timestamp when the import job data was last modified.
-
#metadata ⇒ Hash<String,String>
The metadata fields of the imported Amazon Q in Connect resources.
-
#status ⇒ String
The status of the import job.
-
#upload_id ⇒ String
A pointer to the uploaded asset.
-
#url ⇒ String
The download link to the resource file that is uploaded to the import job.
-
#url_expiry ⇒ Time
The expiration time of the URL as an epoch timestamp.
Instance Attribute Details
#created_time ⇒ Time
The timestamp when the import job was created.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#external_source_configuration ⇒ Types::ExternalSourceConfiguration
The configuration information of the external data source.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#failed_record_report ⇒ String
The link to download the information of resource data that failed to be imported.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#import_job_id ⇒ String
The identifier of the import job.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#import_job_type ⇒ String
The type of the import job.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the import job data was last modified.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata fields of the imported Amazon Q in Connect resources.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#status ⇒ String
The status of the import job.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#upload_id ⇒ String
A pointer to the uploaded asset. This value is returned by StartContentUpload.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#url ⇒ String
The download link to the resource file that is uploaded to the import job.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |
#url_expiry ⇒ Time
The expiration time of the URL as an epoch timestamp.
5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 5967 class ImportJobData < Struct.new( :import_job_id, :knowledge_base_id, :upload_id, :knowledge_base_arn, :import_job_type, :status, :url, :failed_record_report, :url_expiry, :created_time, :last_modified_time, :metadata, :external_source_configuration) SENSITIVE = [:url, :failed_record_report] include Aws::Structure end |