Class: Aws::QConnect::Types::ListContentAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_idString

The identifier of the content.

Returns:

  • (String)


6741
6742
6743
6744
6745
6746
6747
6748
# File 'lib/aws-sdk-qconnect/types.rb', line 6741

class ListContentAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :knowledge_base_id,
  :content_id)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The identifier of the knowledge base.

Returns:

  • (String)


6741
6742
6743
6744
6745
6746
6747
6748
# File 'lib/aws-sdk-qconnect/types.rb', line 6741

class ListContentAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :knowledge_base_id,
  :content_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per page.

Returns:

  • (Integer)


6741
6742
6743
6744
6745
6746
6747
6748
# File 'lib/aws-sdk-qconnect/types.rb', line 6741

class ListContentAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :knowledge_base_id,
  :content_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


6741
6742
6743
6744
6745
6746
6747
6748
# File 'lib/aws-sdk-qconnect/types.rb', line 6741

class ListContentAssociationsRequest < Struct.new(
  :next_token,
  :max_results,
  :knowledge_base_id,
  :content_id)
  SENSITIVE = []
  include Aws::Structure
end