Class: Aws::QConnect::Types::ListContentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListContentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#knowledge_base_id ⇒ String
The identifier of the knowledge base. This should not be a QUICK_RESPONSES type knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
6786 6787 6788 6789 6790 6791 6792 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6786 class ListContentsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
6786 6787 6788 6789 6790 6791 6792 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6786 class ListContentsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
6786 6787 6788 6789 6790 6791 6792 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6786 class ListContentsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id) SENSITIVE = [] include Aws::Structure end |