Class: Aws::QConnect::Types::ListContentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListContentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_summaries ⇒ Array<Types::ContentSummary>
Information about the content.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#content_summaries ⇒ Array<Types::ContentSummary>
Information about the content.
6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6805 class ListContentsResponse < Struct.new( :content_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
6805 6806 6807 6808 6809 6810 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6805 class ListContentsResponse < Struct.new( :content_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |