Class: Aws::QConnect::Types::ListKnowledgeBasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListKnowledgeBasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per page.
6868 6869 6870 6871 6872 6873 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6868 class ListKnowledgeBasesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
6868 6869 6870 6871 6872 6873 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6868 class ListKnowledgeBasesRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |