Class: Aws::QConnect::Types::ListMessageTemplateVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListMessageTemplateVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#message_template_id ⇒ String
The identifier of the message template.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#knowledge_base_id ⇒ String
The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6915 class ListMessageTemplateVersionsRequest < Struct.new( :knowledge_base_id, :message_template_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6915 class ListMessageTemplateVersionsRequest < Struct.new( :knowledge_base_id, :message_template_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#message_template_id ⇒ String
The identifier of the message template. Can be either the ID or the ARN. It cannot contain any qualifier.
6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6915 class ListMessageTemplateVersionsRequest < Struct.new( :knowledge_base_id, :message_template_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
6915 6916 6917 6918 6919 6920 6921 6922 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6915 class ListMessageTemplateVersionsRequest < Struct.new( :knowledge_base_id, :message_template_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |