Class: Aws::QConnect::Types::ListMessagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListMessagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#filter ⇒ String
The filter criteria for listing messages.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#session_id ⇒ String
The identifier of the Amazon Q in Connect session.
Instance Attribute Details
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7009 class ListMessagesRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ String
The filter criteria for listing messages.
7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7009 class ListMessagesRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7009 class ListMessagesRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7009 class ListMessagesRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The identifier of the Amazon Q in Connect session.
7009 7010 7011 7012 7013 7014 7015 7016 7017 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7009 class ListMessagesRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results, :filter) SENSITIVE = [] include Aws::Structure end |