Class: Aws::QConnect::Types::ListModelsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListModelsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#model_summaries ⇒ Array<Types::ModelSummary>
The summaries of the models available to the assistant.
-
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
Instance Attribute Details
#model_summaries ⇒ Array<Types::ModelSummary>
The summaries of the models available to the assistant.
7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7087 class ListModelsResponse < Struct.new( :model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are additional results, this is the token for the next set of results.
7087 7088 7089 7090 7091 7092 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7087 class ListModelsResponse < Struct.new( :model_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |