Class: Aws::QConnect::Types::ListSpansRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListSpansRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
UUID or ARN of the Connect AI Assistant resource.
-
#max_results ⇒ Integer
Maximum number of spans to return per page.
-
#next_token ⇒ String
Pagination token for retrieving the next page of results.
-
#session_id ⇒ String
UUID or ARN of the Connect AI Session resource.
Instance Attribute Details
#assistant_id ⇒ String
UUID or ARN of the Connect AI Assistant resource
7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7156 class ListSpansRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of spans to return per page
7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7156 class ListSpansRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token for retrieving the next page of results
7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7156 class ListSpansRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
UUID or ARN of the Connect AI Session resource
7156 7157 7158 7159 7160 7161 7162 7163 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7156 class ListSpansRequest < Struct.new( :assistant_id, :session_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |