Class: Aws::QConnect::Types::MessageTemplateBodyContentProvider

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Note:

MessageTemplateBodyContentProvider is a union - when making an API calls you must set exactly one of the members.

Note:

MessageTemplateBodyContentProvider is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MessageTemplateBodyContentProvider corresponding to the set member.

The container of the message template body.

Direct Known Subclasses

Content, Unknown

Defined Under Namespace

Classes: Content, Unknown

Constant Summary collapse

SENSITIVE =
[:content]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The content of the message template.

Returns:

  • (String)


7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
# File 'lib/aws-sdk-qconnect/types.rb', line 7426

class MessageTemplateBodyContentProvider < Struct.new(
  :content,
  :unknown)
  SENSITIVE = [:content]
  include Aws::Structure
  include Aws::Structure::Union

  class Content < MessageTemplateBodyContentProvider; end
  class Unknown < MessageTemplateBodyContentProvider; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7426
7427
7428
# File 'lib/aws-sdk-qconnect/types.rb', line 7426

def unknown
  @unknown
end