Class: Aws::QConnect::Types::MessageTemplateQueryField
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::MessageTemplateQueryField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The message template fields to query message templates by. The following is the list of supported field names:
-
name
-
description
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_fuzziness ⇒ Boolean
Whether the query expects only exact matches on the attribute field values.
-
#name ⇒ String
The name of the attribute to query the message templates by.
-
#operator ⇒ String
The operator to use for matching attribute field values in the query.
-
#priority ⇒ String
The importance of the attribute field when calculating query result relevancy scores.
-
#values ⇒ Array<String>
The values of the attribute to query the message templates by.
Instance Attribute Details
#allow_fuzziness ⇒ Boolean
Whether the query expects only exact matches on the attribute field values. The results of the query will only include exact matches if this parameter is set to false.
7728 7729 7730 7731 7732 7733 7734 7735 7736 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7728 class MessageTemplateQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the attribute to query the message templates by.
7728 7729 7730 7731 7732 7733 7734 7735 7736 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7728 class MessageTemplateQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ String
The operator to use for matching attribute field values in the query.
7728 7729 7730 7731 7732 7733 7734 7735 7736 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7728 class MessageTemplateQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The importance of the attribute field when calculating query result relevancy scores. The value set for this parameter affects the ordering of search results.
7728 7729 7730 7731 7732 7733 7734 7735 7736 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7728 class MessageTemplateQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The values of the attribute to query the message templates by.
7728 7729 7730 7731 7732 7733 7734 7735 7736 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7728 class MessageTemplateQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |