Class: Aws::QConnect::Types::MessageTemplateSearchResultData
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::MessageTemplateSearchResultData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The result of message template search.
Constant Summary collapse
- SENSITIVE =
[:channel]
Instance Attribute Summary collapse
-
#channel ⇒ String
The channel of the message template.
-
#channel_subtype ⇒ String
The channel subtype this message template applies to.
-
#created_time ⇒ Time
The timestamp when the message template was created.
-
#description ⇒ String
The description of the message template.
-
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the grouping of Amazon Q in Connect users.
-
#is_active ⇒ Boolean
Whether the version of the message template is activated.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#language ⇒ String
The language code value for the language in which the quick response is written.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the message template data.
-
#last_modified_time ⇒ Time
The timestamp when the message template data was last modified.
-
#message_template_arn ⇒ String
The Amazon Resource Name (ARN) of the message template.
-
#message_template_id ⇒ String
The identifier of the message template.
-
#name ⇒ String
The name of the message template.
-
#source_configuration_summary ⇒ Types::MessageTemplateSourceConfigurationSummary
The source configuration summary of the message template.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
-
#version_number ⇒ Integer
The version number of the message template version.
Instance Attribute Details
#channel ⇒ String
The channel of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#channel_subtype ⇒ String
The channel subtype this message template applies to.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the message template was created.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#description ⇒ String
The description of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the grouping of Amazon Q in Connect users.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#is_active ⇒ Boolean
Whether the version of the message template is activated.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#language ⇒ String
The language code value for the language in which the quick response is written. The supported language codes include ‘de_DE`, `en_US`, `es_ES`, `fr_FR`, `id_ID`, `it_IT`, `ja_JP`, `ko_KR`, `pt_BR`, `zh_CN`, `zh_TW`
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the message template data.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the message template data was last modified.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#message_template_arn ⇒ String
The Amazon Resource Name (ARN) of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#message_template_id ⇒ String
The identifier of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#name ⇒ String
The name of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#source_configuration_summary ⇒ Types::MessageTemplateSourceConfigurationSummary
The source configuration summary of the message template.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#version_number ⇒ Integer
The version number of the message template version.
7842 7843 7844 7845 7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7842 class MessageTemplateSearchResultData < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :is_active, :version_number, :description, :source_configuration_summary, :grouping_configuration, :language, :tags) SENSITIVE = [:channel] include Aws::Structure end |