Class: Aws::QConnect::Types::MessageTemplateSourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Note:

MessageTemplateSourceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

MessageTemplateSourceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MessageTemplateSourceConfiguration corresponding to the set member.

The container of message template source configuration.

Direct Known Subclasses

Unknown, WhatsApp

Defined Under Namespace

Classes: Unknown, WhatsApp

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7877
7878
7879
# File 'lib/aws-sdk-qconnect/types.rb', line 7877

def unknown
  @unknown
end

#whats_appTypes::WhatsAppMessageTemplateSourceConfiguration

The sourceConfiguration of the message template that applies to the WHATSAPP channel subtype.



7877
7878
7879
7880
7881
7882
7883
7884
7885
7886
# File 'lib/aws-sdk-qconnect/types.rb', line 7877

class MessageTemplateSourceConfiguration < Struct.new(
  :whats_app,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class WhatsApp < MessageTemplateSourceConfiguration; end
  class Unknown < MessageTemplateSourceConfiguration; end
end