Class: Aws::QConnect::Types::MessageTemplateSourceConfigurationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Note:

MessageTemplateSourceConfigurationSummary is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MessageTemplateSourceConfigurationSummary corresponding to the set member.

The container of message template source configuration summary.

Direct Known Subclasses

Unknown, WhatsApp

Defined Under Namespace

Classes: Unknown, WhatsApp

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7899
7900
7901
# File 'lib/aws-sdk-qconnect/types.rb', line 7899

def unknown
  @unknown
end

#whats_appTypes::WhatsAppMessageTemplateSourceConfigurationSummary

The sourceConfiguration summary of the message template that applies to the WHATSAPP channel subtype.



7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
# File 'lib/aws-sdk-qconnect/types.rb', line 7899

class MessageTemplateSourceConfigurationSummary < Struct.new(
  :whats_app,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class WhatsApp < MessageTemplateSourceConfigurationSummary; end
  class Unknown < MessageTemplateSourceConfigurationSummary; end
end