Class: Aws::QConnect::Types::MessageTemplateSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::MessageTemplateSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The summary of the message template.
Constant Summary collapse
- SENSITIVE =
[:channel]
Instance Attribute Summary collapse
-
#active_version_number ⇒ Integer
The version number of the message template version that is activated.
-
#channel ⇒ String
The channel this message template applies to.
-
#channel_subtype ⇒ String
The channel subtype this message template applies to.
-
#created_time ⇒ Time
The timestamp when the message template was created.
-
#description ⇒ String
The description of the message template.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the message template data.
-
#last_modified_time ⇒ Time
The timestamp when the message template data was last modified.
-
#message_template_arn ⇒ String
The Amazon Resource Name (ARN) of the message template.
-
#message_template_id ⇒ String
The identifier of the message template.
-
#name ⇒ String
The name of the message template.
-
#source_configuration ⇒ Types::MessageTemplateSourceConfiguration
The container of message template source configuration.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#active_version_number ⇒ Integer
The version number of the message template version that is activated.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#channel ⇒ String
The channel this message template applies to.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#channel_subtype ⇒ String
The channel subtype this message template applies to.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the message template was created.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#description ⇒ String
The description of the message template.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the message template data.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the message template data was last modified.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#message_template_arn ⇒ String
The Amazon Resource Name (ARN) of the message template.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#message_template_id ⇒ String
The identifier of the message template.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#name ⇒ String
The name of the message template.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#source_configuration ⇒ Types::MessageTemplateSourceConfiguration
The container of message template source configuration.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
7973 7974 7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7973 class MessageTemplateSummary < Struct.new( :message_template_arn, :message_template_id, :knowledge_base_arn, :knowledge_base_id, :name, :channel, :channel_subtype, :created_time, :last_modified_time, :last_modified_by, :source_configuration, :active_version_number, :description, :tags) SENSITIVE = [:channel] include Aws::Structure end |