Class: Aws::QConnect::Types::ModelSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

The summary of a model available to an Amazon Q in Connect assistant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cross_region_statusString

The cross-region availability status of the model. ‘NONE` indicates the model is only available in a single region, `REGIONAL` indicates the model is available through regional inference, and `GLOBAL` indicates the model is available through global cross-region inference.

Returns:

  • (String)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The display name of the model.

Returns:

  • (String)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#end_of_life_timestampTime

The timestamp when the model will reach end of life and no longer be available for use.

Returns:

  • (Time)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#legacy_timestampTime

The timestamp when the model lifecycle will transition from ‘ACTIVE` to `LEGACY`.

Returns:

  • (Time)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The identifier of the model.

Returns:

  • (String)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#model_lifecycleString

The current lifecycle of the model. ‘ACTIVE` indicates the model is recommended for use and `LEGACY` indicates the model is still usable but is deprecated.

Returns:

  • (String)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#supported_ai_prompt_typesArray<String>

The list of AI Prompt types that the model supports.

Returns:

  • (Array<String>)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#supports_prompt_cachingBoolean

Whether the model supports prompt caching.

Returns:

  • (Boolean)


8090
8091
8092
8093
8094
8095
8096
8097
8098
8099
8100
8101
# File 'lib/aws-sdk-qconnect/types.rb', line 8090

class ModelSummary < Struct.new(
  :model_id,
  :display_name,
  :cross_region_status,
  :supports_prompt_caching,
  :supported_ai_prompt_types,
  :model_lifecycle,
  :legacy_timestamp,
  :end_of_life_timestamp)
  SENSITIVE = []
  include Aws::Structure
end