Class: Aws::QConnect::Types::QueryAssistantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::QueryAssistantRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:query_text]
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#override_knowledge_base_search_type ⇒ String
The search type to be used against the Knowledge Base for this request.
-
#query_condition ⇒ Array<Types::QueryCondition>
Information about how to query content.
-
#query_input_data ⇒ Types::QueryInputData
Information about the query.
-
#query_text ⇒ String
The text to search for.
-
#session_id ⇒ String
The identifier of the Amazon Q in Connect session.
Instance Attribute Details
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#override_knowledge_base_search_type ⇒ String
The search type to be used against the Knowledge Base for this request. The values can be ‘SEMANTIC` which uses vector embeddings or `HYBRID` which use vector embeddings and raw text.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#query_condition ⇒ Array<Types::QueryCondition>
Information about how to query content.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#query_input_data ⇒ Types::QueryInputData
Information about the query.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#query_text ⇒ String
The text to search for.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |
#session_id ⇒ String
The identifier of the Amazon Q in Connect session. Can be either the ID or the ARN. URLs cannot contain the ARN.
8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8804 class QueryAssistantRequest < Struct.new( :assistant_id, :query_text, :next_token, :max_results, :session_id, :query_condition, :query_input_data, :override_knowledge_base_search_type) SENSITIVE = [:query_text] include Aws::Structure end |