Class: Aws::QConnect::Types::QuickResponseQueryField
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::QuickResponseQueryField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The quick response fields to query quick responses by.
The following is the list of supported field names.
-
content
-
name
-
description
-
shortcutKey
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_fuzziness ⇒ Boolean
Whether the query expects only exact matches on the attribute field values.
-
#name ⇒ String
The name of the attribute to query the quick responses by.
-
#operator ⇒ String
The operator to use for matching attribute field values in the query.
-
#priority ⇒ String
The importance of the attribute field when calculating query result relevancy scores.
-
#values ⇒ Array<String>
The values of the attribute to query the quick responses by.
Instance Attribute Details
#allow_fuzziness ⇒ Boolean
Whether the query expects only exact matches on the attribute field values. The results of the query will only include exact matches if this parameter is set to false.
9258 9259 9260 9261 9262 9263 9264 9265 9266 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9258 class QuickResponseQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the attribute to query the quick responses by.
9258 9259 9260 9261 9262 9263 9264 9265 9266 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9258 class QuickResponseQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#operator ⇒ String
The operator to use for matching attribute field values in the query.
9258 9259 9260 9261 9262 9263 9264 9265 9266 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9258 class QuickResponseQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ String
The importance of the attribute field when calculating query result relevancy scores. The value set for this parameter affects the ordering of search results.
9258 9259 9260 9261 9262 9263 9264 9265 9266 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9258 class QuickResponseQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
The values of the attribute to query the quick responses by.
9258 9259 9260 9261 9262 9263 9264 9265 9266 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9258 class QuickResponseQueryField < Struct.new( :name, :values, :operator, :allow_fuzziness, :priority) SENSITIVE = [] include Aws::Structure end |