Class: Aws::QConnect::Types::QuickResponseSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::QuickResponseSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The summary information about the quick response.
Constant Summary collapse
- SENSITIVE =
[:channels]
Instance Attribute Summary collapse
-
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to.
-
#content_type ⇒ String
The media type of the quick response content.
-
#created_time ⇒ Time
The timestamp when the quick response was created.
-
#description ⇒ String
The description of the quick response.
-
#is_active ⇒ Boolean
Whether the quick response is active.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response data.
-
#last_modified_time ⇒ Time
The timestamp when the quick response summary was last modified.
-
#name ⇒ String
The name of the quick response.
-
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
-
#quick_response_id ⇒ String
The identifier of the quick response.
-
#status ⇒ String
The resource status of the quick response.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to. The supported contact channel types include ‘Chat`.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#content_type ⇒ String
The media type of the quick response content.
-
Use ‘application/x.quickresponse;format=plain` for quick response written in plain text.
-
Use ‘application/x.quickresponse;format=markdown` for quick response written in richtext.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the quick response was created.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#description ⇒ String
The description of the quick response.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#is_active ⇒ Boolean
Whether the quick response is active.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response data.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the quick response summary was last modified.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#name ⇒ String
The name of the quick response.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#quick_response_id ⇒ String
The identifier of the quick response.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#status ⇒ String
The resource status of the quick response.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9488 class QuickResponseSummary < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :description, :last_modified_by, :is_active, :channels, :tags) SENSITIVE = [:channels] include Aws::Structure end |