Class: Aws::QConnect::Types::RuntimeSessionDataValue

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Note:

RuntimeSessionDataValue is a union - when making an API calls you must set exactly one of the members.

Note:

RuntimeSessionDataValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RuntimeSessionDataValue corresponding to the set member.

A union type that specifies the data stored on the session.

Direct Known Subclasses

StringValue, Unknown

Defined Under Namespace

Classes: StringValue, Unknown

Constant Summary collapse

SENSITIVE =
[:string_value]

Instance Attribute Summary collapse

Instance Attribute Details

#string_valueString

The string value of the data stored on the session.

Returns:

  • (String)


10048
10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/aws-sdk-qconnect/types.rb', line 10048

class RuntimeSessionDataValue < Struct.new(
  :string_value,
  :unknown)
  SENSITIVE = [:string_value]
  include Aws::Structure
  include Aws::Structure::Union

  class StringValue < RuntimeSessionDataValue; end
  class Unknown < RuntimeSessionDataValue; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10048
10049
10050
# File 'lib/aws-sdk-qconnect/types.rb', line 10048

def unknown
  @unknown
end