Class: Aws::QConnect::Types::SearchContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SearchContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_expression ⇒ Types::SearchExpression
The search expression to filter results.
Instance Attribute Details
#knowledge_base_id ⇒ String
The identifier of the knowledge base. This should not be a QUICK_RESPONSES type knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
10110 10111 10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10110 class SearchContentRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
10110 10111 10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10110 class SearchContentRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
10110 10111 10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10110 class SearchContentRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#search_expression ⇒ Types::SearchExpression
The search expression to filter results.
10110 10111 10112 10113 10114 10115 10116 10117 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10110 class SearchContentRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :search_expression) SENSITIVE = [] include Aws::Structure end |