Class: Aws::QConnect::Types::SearchMessageTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SearchMessageTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_expression ⇒ Types::MessageTemplateSearchExpression
The search expression for querying the message template.
Instance Attribute Details
#knowledge_base_id ⇒ String
The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
10172 10173 10174 10175 10176 10177 10178 10179 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10172 class SearchMessageTemplatesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
10172 10173 10174 10175 10176 10177 10178 10179 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10172 class SearchMessageTemplatesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
10172 10173 10174 10175 10176 10177 10178 10179 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10172 class SearchMessageTemplatesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#search_expression ⇒ Types::MessageTemplateSearchExpression
The search expression for querying the message template.
10172 10173 10174 10175 10176 10177 10178 10179 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10172 class SearchMessageTemplatesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |