Class: Aws::QConnect::Types::SearchQuickResponsesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SearchQuickResponsesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:attributes]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
The [user-defined Amazon Connect contact attributes] to be resolved when search results are returned.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_expression ⇒ Types::QuickResponseSearchExpression
The search expression for querying the quick response.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
The [user-defined Amazon Connect contact attributes] to be resolved when search results are returned.
[1]: docs.aws.amazon.com/connect/latest/adminguide/connect-attrib-list.html#user-defined-attributes
10230 10231 10232 10233 10234 10235 10236 10237 10238 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10230 class SearchQuickResponsesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results, :attributes) SENSITIVE = [:attributes] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base. This should be a QUICK_RESPONSES type knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
10230 10231 10232 10233 10234 10235 10236 10237 10238 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10230 class SearchQuickResponsesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results, :attributes) SENSITIVE = [:attributes] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
10230 10231 10232 10233 10234 10235 10236 10237 10238 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10230 class SearchQuickResponsesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results, :attributes) SENSITIVE = [:attributes] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
10230 10231 10232 10233 10234 10235 10236 10237 10238 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10230 class SearchQuickResponsesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results, :attributes) SENSITIVE = [:attributes] include Aws::Structure end |
#search_expression ⇒ Types::QuickResponseSearchExpression
The search expression for querying the quick response.
10230 10231 10232 10233 10234 10235 10236 10237 10238 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10230 class SearchQuickResponsesRequest < Struct.new( :knowledge_base_id, :search_expression, :next_token, :max_results, :attributes) SENSITIVE = [:attributes] include Aws::Structure end |