Class: Aws::QConnect::Types::SearchSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SearchSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_expression ⇒ Types::SearchExpression
The search expression to filter results.
Instance Attribute Details
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
10280 10281 10282 10283 10284 10285 10286 10287 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10280 class SearchSessionsRequest < Struct.new( :next_token, :max_results, :assistant_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
10280 10281 10282 10283 10284 10285 10286 10287 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10280 class SearchSessionsRequest < Struct.new( :next_token, :max_results, :assistant_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
10280 10281 10282 10283 10284 10285 10286 10287 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10280 class SearchSessionsRequest < Struct.new( :next_token, :max_results, :assistant_id, :search_expression) SENSITIVE = [] include Aws::Structure end |
#search_expression ⇒ Types::SearchExpression
The search expression to filter results.
10280 10281 10282 10283 10284 10285 10286 10287 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10280 class SearchSessionsRequest < Struct.new( :next_token, :max_results, :assistant_id, :search_expression) SENSITIVE = [] include Aws::Structure end |