Class: Aws::QConnect::Types::SendMessageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_agent_idString

The identifier of the AI Agent to use for processing the message.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#assistant_idString

The identifier of the Amazon Q in Connect assistant.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the AWS SDK populates this field.For more information about idempotency, see Making retries safe with idempotent APIs.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::MessageConfiguration



10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#conversation_contextTypes::ConversationContext

The conversation context before the Amazon Q in Connect session.



10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#messageTypes::MessageInput

The message data to submit to the Amazon Q in Connect session.

Returns:



10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#metadataHash<String,String>

Additional metadata for the message.

Returns:

  • (Hash<String,String>)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#orchestrator_use_caseString

The orchestrator use case for message processing.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#origin_request_idString

Request identifier from the origin system, used for end-to-end tracing across spans.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The identifier of the Amazon Q in Connect session.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The message type.

Returns:

  • (String)


10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
# File 'lib/aws-sdk-qconnect/types.rb', line 10467

class SendMessageRequest < Struct.new(
  :assistant_id,
  :session_id,
  :type,
  :message,
  :ai_agent_id,
  :conversation_context,
  :configuration,
  :client_token,
  :orchestrator_use_case,
  :metadata,
  :origin_request_id)
  SENSITIVE = []
  include Aws::Structure
end