Class: Aws::QConnect::Types::ServerSideEncryptionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

The configuration information for the customer managed key used for encryption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_idString

The customer managed key used for encryption. For more information about setting up a customer managed key for Amazon Q in Connect, see [Enable Amazon Q in Connect for your instance]. For information about valid ID values, see [Key identifiers (KeyId)].

[1]: docs.aws.amazon.com/connect/latest/adminguide/enable-q.html [2]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id

Returns:

  • (String)


10413
10414
10415
10416
10417
# File 'lib/aws-sdk-qconnect/types.rb', line 10413

class ServerSideEncryptionConfiguration < Struct.new(
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end