Class: Aws::QConnect::Types::Span

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

A span represents a unit of work during AI agent execution, capturing timing, status, and contextual attributes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assistant_idString

UUID of the Connect AI Assistant resource

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#attributesTypes::SpanAttributes

Span-specific contextual attributes



10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#end_timestampTime

Operation end time in milliseconds since epoch

Returns:

  • (Time)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#origin_request_idString

The origin request identifier for end-to-end tracing.

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#parent_span_idString

Parent span identifier for hierarchy. Null for root spans.

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The service request ID that initiated the operation

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

UUID of the Connect AI Session resource

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#span_idString

Unique span identifier

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#span_nameString

Service-defined operation name

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#span_typeString

Operation relationship type

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#start_timestampTime

Operation start time in milliseconds since epoch

Returns:

  • (Time)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Span completion status

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#status_descriptionString

Human-readable error description when status is ERROR or TIMEOUT

Returns:

  • (String)


10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
# File 'lib/aws-sdk-qconnect/types.rb', line 10668

class Span < Struct.new(
  :span_id,
  :assistant_id,
  :session_id,
  :parent_span_id,
  :span_name,
  :span_type,
  :start_timestamp,
  :end_timestamp,
  :status,
  :status_description,
  :request_id,
  :origin_request_id,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end