Class: Aws::QConnect::Types::SpanAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SpanAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Contextual attributes capturing operation details, LLM configuration, usage metrics, and conversation data
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Amazon Connect agent ID.
-
#ai_agent_arn ⇒ String
AI agent ARN.
-
#ai_agent_id ⇒ String
AI agent identifier.
-
#ai_agent_invoker ⇒ String
Entity that invoked the AI agent.
-
#ai_agent_name ⇒ String
AI agent name.
-
#ai_agent_orchestrator_use_case ⇒ String
AI agent orchestrator use case.
-
#ai_agent_type ⇒ String
AI agent type.
-
#ai_agent_version ⇒ Integer
AI agent version number.
-
#cache_read_input_tokens ⇒ Integer
Number of input tokens that were retrieved from cache.
-
#cache_write_input_tokens ⇒ Integer
Number of input tokens that were written to cache in this request.
-
#contact_id ⇒ String
Amazon Connect contact identifier.
-
#error_type ⇒ String
Error classification if span failed (e.g., throttle, timeout).
-
#initial_contact_id ⇒ String
Amazon Connect contact identifier.
-
#input_messages ⇒ Array<Types::SpanMessage>
Input message collection sent to LLM.
-
#instance_arn ⇒ String
Amazon Connect instance ARN.
-
#operation_name ⇒ String
Action being performed.
-
#output_messages ⇒ Array<Types::SpanMessage>
Output message collection received from LLM.
-
#prompt_arn ⇒ String
AI prompt ARN.
-
#prompt_id ⇒ String
AI prompt identifier.
-
#prompt_name ⇒ String
AI prompt name.
-
#prompt_type ⇒ String
AI prompt type.
-
#prompt_version ⇒ Integer
AI prompt version number.
-
#provider_name ⇒ String
Model provider identifier (e.g., aws.bedrock).
-
#request_max_tokens ⇒ Integer
Maximum tokens configured for generation.
-
#request_model ⇒ String
LLM model ID for request (e.g., anthropic.claude-3-sonnet).
-
#response_finish_reasons ⇒ Array<String>
Generation termination reasons (e.g., stop, max_tokens).
-
#response_model ⇒ String
Actual model used for response (usually matches requestModel).
-
#session_name ⇒ String
Session name.
-
#system_instructions ⇒ Array<Types::SpanMessageValue>
System prompt instructions.
-
#temperature ⇒ Float
Sampling temperature for generation.
-
#time_to_first_token_ms ⇒ Integer
Time to first token in milliseconds, measured from when Amazon Bedrock was invoked to when the first token was returned.
-
#top_p ⇒ Float
Top-p sampling parameter for generation.
-
#usage_input_tokens ⇒ Integer
Number of input tokens in prompt.
-
#usage_output_tokens ⇒ Integer
Number of output tokens in response.
-
#usage_total_tokens ⇒ Integer
Total tokens consumed (input + output).
Instance Attribute Details
#agent_id ⇒ String
Amazon Connect agent ID
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_arn ⇒ String
AI agent ARN
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_id ⇒ String
AI agent identifier
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_invoker ⇒ String
Entity that invoked the AI agent
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_name ⇒ String
AI agent name
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_orchestrator_use_case ⇒ String
AI agent orchestrator use case
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_type ⇒ String
AI agent type
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#ai_agent_version ⇒ Integer
AI agent version number
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#cache_read_input_tokens ⇒ Integer
Number of input tokens that were retrieved from cache
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#cache_write_input_tokens ⇒ Integer
Number of input tokens that were written to cache in this request
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
Amazon Connect contact identifier
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#error_type ⇒ String
Error classification if span failed (e.g., throttle, timeout)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#initial_contact_id ⇒ String
Amazon Connect contact identifier
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#input_messages ⇒ Array<Types::SpanMessage>
Input message collection sent to LLM
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
Amazon Connect instance ARN
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
Action being performed
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#output_messages ⇒ Array<Types::SpanMessage>
Output message collection received from LLM
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#prompt_arn ⇒ String
AI prompt ARN
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#prompt_id ⇒ String
AI prompt identifier
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#prompt_name ⇒ String
AI prompt name
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#prompt_type ⇒ String
AI prompt type
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#prompt_version ⇒ Integer
AI prompt version number
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#provider_name ⇒ String
Model provider identifier (e.g., aws.bedrock)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#request_max_tokens ⇒ Integer
Maximum tokens configured for generation
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#request_model ⇒ String
LLM model ID for request (e.g., anthropic.claude-3-sonnet)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#response_finish_reasons ⇒ Array<String>
Generation termination reasons (e.g., stop, max_tokens)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#response_model ⇒ String
Actual model used for response (usually matches requestModel)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#session_name ⇒ String
Session name
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#system_instructions ⇒ Array<Types::SpanMessageValue>
System prompt instructions
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#temperature ⇒ Float
Sampling temperature for generation
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#time_to_first_token_ms ⇒ Integer
Time to first token in milliseconds, measured from when Amazon Bedrock was invoked to when the first token was returned
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#top_p ⇒ Float
Top-p sampling parameter for generation
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#usage_input_tokens ⇒ Integer
Number of input tokens in prompt
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#usage_output_tokens ⇒ Integer
Number of output tokens in response
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |
#usage_total_tokens ⇒ Integer
Total tokens consumed (input + output)
10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 10958 10959 10960 10961 10962 10963 10964 10965 10966 10967 10968 10969 10970 10971 10972 10973 10974 10975 10976 10977 10978 10979 10980 10981 10982 10983 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10945 class SpanAttributes < Struct.new( :operation_name, :provider_name, :error_type, :agent_id, :instance_arn, :contact_id, :initial_contact_id, :session_name, :ai_agent_arn, :ai_agent_type, :ai_agent_name, :ai_agent_id, :ai_agent_version, :ai_agent_invoker, :ai_agent_orchestrator_use_case, :request_model, :request_max_tokens, :temperature, :top_p, :response_model, :response_finish_reasons, :usage_input_tokens, :usage_output_tokens, :usage_total_tokens, :cache_read_input_tokens, :cache_write_input_tokens, :input_messages, :output_messages, :system_instructions, :prompt_arn, :prompt_id, :prompt_type, :prompt_name, :prompt_version, :time_to_first_token_ms) SENSITIVE = [] include Aws::Structure end |