Class: Aws::QConnect::Types::SpanCitation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

A citation that spans a specific range of text.

Constant Summary collapse

SENSITIVE =
[:title]

Instance Attribute Summary collapse

Instance Attribute Details

#content_idString

The identifier of the content being cited in the span.

Returns:

  • (String)


10893
10894
10895
10896
10897
10898
10899
10900
# File 'lib/aws-sdk-qconnect/types.rb', line 10893

class SpanCitation < Struct.new(
  :content_id,
  :title,
  :knowledge_base_id,
  :knowledge_base_arn)
  SENSITIVE = [:title]
  include Aws::Structure
end

#knowledge_base_arnString

The Amazon Resource Name (ARN) of the knowledge base containing the cited content.

Returns:

  • (String)


10893
10894
10895
10896
10897
10898
10899
10900
# File 'lib/aws-sdk-qconnect/types.rb', line 10893

class SpanCitation < Struct.new(
  :content_id,
  :title,
  :knowledge_base_id,
  :knowledge_base_arn)
  SENSITIVE = [:title]
  include Aws::Structure
end

#knowledge_base_idString

The identifier of the knowledge base containing the cited content.

Returns:

  • (String)


10893
10894
10895
10896
10897
10898
10899
10900
# File 'lib/aws-sdk-qconnect/types.rb', line 10893

class SpanCitation < Struct.new(
  :content_id,
  :title,
  :knowledge_base_id,
  :knowledge_base_arn)
  SENSITIVE = [:title]
  include Aws::Structure
end

#titleString

The title of the content being cited in the span.

Returns:

  • (String)


10893
10894
10895
10896
10897
10898
10899
10900
# File 'lib/aws-sdk-qconnect/types.rb', line 10893

class SpanCitation < Struct.new(
  :content_id,
  :title,
  :knowledge_base_id,
  :knowledge_base_arn)
  SENSITIVE = [:title]
  include Aws::Structure
end