Class: Aws::QConnect::Types::SpanMessageValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SpanMessageValue
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Note:
SpanMessageValue is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SpanMessageValue corresponding to the set member.
Message content value - can be text, tool invocation, tool result, or reasoning
Direct Known Subclasses
Defined Under Namespace
Classes: Reasoning, Text, ToolResult, ToolUse, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reasoning ⇒ Types::SpanReasoningValue
Model reasoning and it’s internal decision making process.
-
#text ⇒ Types::SpanTextValue
Text message content.
-
#tool_result ⇒ Types::SpanToolResultValue
Tool result message content.
-
#tool_use ⇒ Types::SpanToolUseValue
Tool invocation message content.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#reasoning ⇒ Types::SpanReasoningValue
Model reasoning and it’s internal decision making process
11068 11069 11070 11071 11072 11073 11074 11075 11076 11077 11078 11079 11080 11081 11082 11083 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11068 class SpanMessageValue < Struct.new( :text, :tool_use, :tool_result, :reasoning, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SpanMessageValue; end class ToolUse < SpanMessageValue; end class ToolResult < SpanMessageValue; end class Reasoning < SpanMessageValue; end class Unknown < SpanMessageValue; end end |
#text ⇒ Types::SpanTextValue
Text message content
11068 11069 11070 11071 11072 11073 11074 11075 11076 11077 11078 11079 11080 11081 11082 11083 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11068 class SpanMessageValue < Struct.new( :text, :tool_use, :tool_result, :reasoning, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SpanMessageValue; end class ToolUse < SpanMessageValue; end class ToolResult < SpanMessageValue; end class Reasoning < SpanMessageValue; end class Unknown < SpanMessageValue; end end |
#tool_result ⇒ Types::SpanToolResultValue
Tool result message content
11068 11069 11070 11071 11072 11073 11074 11075 11076 11077 11078 11079 11080 11081 11082 11083 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11068 class SpanMessageValue < Struct.new( :text, :tool_use, :tool_result, :reasoning, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SpanMessageValue; end class ToolUse < SpanMessageValue; end class ToolResult < SpanMessageValue; end class Reasoning < SpanMessageValue; end class Unknown < SpanMessageValue; end end |
#tool_use ⇒ Types::SpanToolUseValue
Tool invocation message content
11068 11069 11070 11071 11072 11073 11074 11075 11076 11077 11078 11079 11080 11081 11082 11083 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11068 class SpanMessageValue < Struct.new( :text, :tool_use, :tool_result, :reasoning, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SpanMessageValue; end class ToolUse < SpanMessageValue; end class ToolResult < SpanMessageValue; end class Reasoning < SpanMessageValue; end class Unknown < SpanMessageValue; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11068 11069 11070 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11068 def unknown @unknown end |