Class: Aws::QConnect::Types::UpdateAIAgentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::UpdateAIAgentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_agent ⇒ Types::AIAgentData
The data of the updated Amazon Q in Connect AI Agent.
Instance Attribute Details
#ai_agent ⇒ Types::AIAgentData
The data of the updated Amazon Q in Connect AI Agent.
11740 11741 11742 11743 11744 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11740 class UpdateAIAgentResponse < Struct.new( :ai_agent) SENSITIVE = [] include Aws::Structure end |