Class: Aws::QConnect::Types::UpdateAIGuardrailResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::UpdateAIGuardrailResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_guardrail ⇒ Types::AIGuardrailData
The data of the updated Amazon Q in Connect AI Guardrail.
Instance Attribute Details
#ai_guardrail ⇒ Types::AIGuardrailData
The data of the updated Amazon Q in Connect AI Guardrail.
11831 11832 11833 11834 11835 |
# File 'lib/aws-sdk-qconnect/types.rb', line 11831 class UpdateAIGuardrailResponse < Struct.new( :ai_guardrail) SENSITIVE = [] include Aws::Structure end |