Class: Aws::QConnect::Types::UpdateAIPromptResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::UpdateAIPromptResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_prompt ⇒ Types::AIPromptData
The data of the updated Amazon Q in Connect AI Prompt.
Instance Attribute Details
#ai_prompt ⇒ Types::AIPromptData
The data of the updated Amazon Q in Connect AI Prompt.
12024 12025 12026 12027 12028 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12024 class UpdateAIPromptResponse < Struct.new( :ai_prompt) SENSITIVE = [] include Aws::Structure end |