Class: Aws::QConnect::Types::UpdateAssistantAIAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ai_agent_typeString

The type of the AI Agent being updated for use by default on the Amazon Q in Connect Assistant.

Returns:

  • (String)


11938
11939
11940
11941
11942
11943
11944
11945
# File 'lib/aws-sdk-qconnect/types.rb', line 11938

class UpdateAssistantAIAgentRequest < Struct.new(
  :assistant_id,
  :ai_agent_type,
  :configuration,
  :orchestrator_use_case)
  SENSITIVE = []
  include Aws::Structure
end

#assistant_idString

The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.

Returns:

  • (String)


11938
11939
11940
11941
11942
11943
11944
11945
# File 'lib/aws-sdk-qconnect/types.rb', line 11938

class UpdateAssistantAIAgentRequest < Struct.new(
  :assistant_id,
  :ai_agent_type,
  :configuration,
  :orchestrator_use_case)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::AIAgentConfigurationData

The configuration of the AI Agent being updated for use by default on the Amazon Q in Connect Assistant.



11938
11939
11940
11941
11942
11943
11944
11945
# File 'lib/aws-sdk-qconnect/types.rb', line 11938

class UpdateAssistantAIAgentRequest < Struct.new(
  :assistant_id,
  :ai_agent_type,
  :configuration,
  :orchestrator_use_case)
  SENSITIVE = []
  include Aws::Structure
end

#orchestrator_use_caseString

The orchestrator use case for the AI Agent being added.

Returns:

  • (String)


11938
11939
11940
11941
11942
11943
11944
11945
# File 'lib/aws-sdk-qconnect/types.rb', line 11938

class UpdateAssistantAIAgentRequest < Struct.new(
  :assistant_id,
  :ai_agent_type,
  :configuration,
  :orchestrator_use_case)
  SENSITIVE = []
  include Aws::Structure
end