Class: Aws::QConnect::Types::UpdateContentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::UpdateContentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_id ⇒ String
The identifier of the content.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#metadata ⇒ Hash<String,String>
A key/value map to store attributes without affecting tagging or recommendations.
-
#override_link_out_uri ⇒ String
The URI for the article.
-
#remove_override_link_out_uri ⇒ Boolean
Unset the existing ‘overrideLinkOutUri` if it exists.
-
#revision_id ⇒ String
The ‘revisionId` of the content resource to update, taken from an earlier call to `GetContent`, `GetContentSummary`, `SearchContent`, or `ListContents`.
-
#title ⇒ String
The title of the content.
-
#upload_id ⇒ String
A pointer to the uploaded asset.
Instance Attribute Details
#content_id ⇒ String
The identifier of the content. Can be either the ID or the ARN. URLs cannot contain the ARN.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base. This should not be a QUICK_RESPONSES type knowledge base. Can be either the ID or the ARN
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
A key/value map to store attributes without affecting tagging or recommendations. For example, when synchronizing data between an external system and Amazon Q in Connect, you can store an external version identifier as metadata to utilize for determining drift.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#override_link_out_uri ⇒ String
The URI for the article. If the knowledge base has a templateUri, setting this argument overrides it for this piece of content. To remove an existing ‘overrideLinkOurUri`, exclude this argument and set `removeOverrideLinkOutUri` to true.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#remove_override_link_out_uri ⇒ Boolean
Unset the existing ‘overrideLinkOutUri` if it exists.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The ‘revisionId` of the content resource to update, taken from an earlier call to `GetContent`, `GetContentSummary`, `SearchContent`, or `ListContents`. If included, this argument acts as an optimistic lock to ensure content was not modified since it was last read. If it has been modified, this API throws a `PreconditionFailedException`.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the content.
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |
#upload_id ⇒ String
A pointer to the uploaded asset. This value is returned by [StartContentUpload].
[1]: docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_StartContentUpload.html
12012 12013 12014 12015 12016 12017 12018 12019 12020 12021 12022 12023 |
# File 'lib/aws-sdk-qconnect/types.rb', line 12012 class UpdateContentRequest < Struct.new( :knowledge_base_id, :content_id, :revision_id, :title, :override_link_out_uri, :remove_override_link_out_uri, :metadata, :upload_id) SENSITIVE = [] include Aws::Structure end |