Class: Aws::QConnect::Types::ListContentAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListContentAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_id ⇒ String
The identifier of the content.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#content_id ⇒ String
The identifier of the content.
6741 6742 6743 6744 6745 6746 6747 6748 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6741 class ListContentAssociationsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :content_id) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
6741 6742 6743 6744 6745 6746 6747 6748 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6741 class ListContentAssociationsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :content_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
6741 6742 6743 6744 6745 6746 6747 6748 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6741 class ListContentAssociationsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :content_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
6741 6742 6743 6744 6745 6746 6747 6748 |
# File 'lib/aws-sdk-qconnect/types.rb', line 6741 class ListContentAssociationsRequest < Struct.new( :next_token, :max_results, :knowledge_base_id, :content_id) SENSITIVE = [] include Aws::Structure end |