Class: Aws::QConnect::Types::ListModelsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ListModelsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_prompt_type ⇒ String
The type of the AI Prompt to filter models by.
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#model_lifecycle ⇒ String
The lifecycle status of models to filter by.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#ai_prompt_type ⇒ String
The type of the AI Prompt to filter models by. When specified, only models that support the given AI Prompt type are returned.
7066 7067 7068 7069 7070 7071 7072 7073 7074 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7066 class ListModelsRequest < Struct.new( :assistant_id, :ai_prompt_type, :model_lifecycle, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN. The assistant's region determines which models are available.
7066 7067 7068 7069 7070 7071 7072 7073 7074 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7066 class ListModelsRequest < Struct.new( :assistant_id, :ai_prompt_type, :model_lifecycle, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
7066 7067 7068 7069 7070 7071 7072 7073 7074 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7066 class ListModelsRequest < Struct.new( :assistant_id, :ai_prompt_type, :model_lifecycle, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#model_lifecycle ⇒ String
The lifecycle status of models to filter by. When specified, only models with the given lifecycle status are returned.
7066 7067 7068 7069 7070 7071 7072 7073 7074 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7066 class ListModelsRequest < Struct.new( :assistant_id, :ai_prompt_type, :model_lifecycle, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
7066 7067 7068 7069 7070 7071 7072 7073 7074 |
# File 'lib/aws-sdk-qconnect/types.rb', line 7066 class ListModelsRequest < Struct.new( :assistant_id, :ai_prompt_type, :model_lifecycle, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |