Class: Aws::QConnect::Types::ModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::ModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The summary of a model available to an Amazon Q in Connect assistant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_region_status ⇒ String
The cross-region availability status of the model.
-
#display_name ⇒ String
The display name of the model.
-
#end_of_life_timestamp ⇒ Time
The timestamp when the model will reach end of life and no longer be available for use.
-
#legacy_timestamp ⇒ Time
The timestamp when the model lifecycle will transition from ‘ACTIVE` to `LEGACY`.
-
#model_id ⇒ String
The identifier of the model.
-
#model_lifecycle ⇒ String
The current lifecycle of the model.
-
#supported_ai_prompt_types ⇒ Array<String>
The list of AI Prompt types that the model supports.
-
#supports_prompt_caching ⇒ Boolean
Whether the model supports prompt caching.
Instance Attribute Details
#cross_region_status ⇒ String
The cross-region availability status of the model. ‘NONE` indicates the model is only available in a single region, `REGIONAL` indicates the model is available through regional inference, and `GLOBAL` indicates the model is available through global cross-region inference.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the model.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#end_of_life_timestamp ⇒ Time
The timestamp when the model will reach end of life and no longer be available for use.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#legacy_timestamp ⇒ Time
The timestamp when the model lifecycle will transition from ‘ACTIVE` to `LEGACY`.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The identifier of the model.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#model_lifecycle ⇒ String
The current lifecycle of the model. ‘ACTIVE` indicates the model is recommended for use and `LEGACY` indicates the model is still usable but is deprecated.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#supported_ai_prompt_types ⇒ Array<String>
The list of AI Prompt types that the model supports.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |
#supports_prompt_caching ⇒ Boolean
Whether the model supports prompt caching.
8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-qconnect/types.rb', line 8090 class ModelSummary < Struct.new( :model_id, :display_name, :cross_region_status, :supports_prompt_caching, :supported_ai_prompt_types, :model_lifecycle, :legacy_timestamp, :end_of_life_timestamp) SENSITIVE = [] include Aws::Structure end |