Class: Aws::QConnect::Types::QuickResponseData
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::QuickResponseData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Information about the quick response.
Constant Summary collapse
- SENSITIVE =
[:channels]
Instance Attribute Summary collapse
-
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to.
-
#content_type ⇒ String
The media type of the quick response content.
-
#contents ⇒ Types::QuickResponseContents
The contents of the quick response.
-
#created_time ⇒ Time
The timestamp when the quick response was created.
-
#description ⇒ String
The description of the quick response.
-
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the user groups that the quick response is accessible to.
-
#is_active ⇒ Boolean
Whether the quick response is active.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#language ⇒ String
The language code value for the language in which the quick response is written.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response data.
-
#last_modified_time ⇒ Time
The timestamp when the quick response data was last modified.
-
#name ⇒ String
The name of the quick response.
-
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
-
#quick_response_id ⇒ String
The identifier of the quick response.
-
#shortcut_key ⇒ String
The shortcut key of the quick response.
-
#status ⇒ String
The status of the quick response data.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to. The supported contact channel types include ‘Chat`.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#content_type ⇒ String
The media type of the quick response content.
-
Use ‘application/x.quickresponse;format=plain` for quick response written in plain text.
-
Use ‘application/x.quickresponse;format=markdown` for quick response written in richtext.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#contents ⇒ Types::QuickResponseContents
The contents of the quick response.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the quick response was created.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#description ⇒ String
The description of the quick response.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the user groups that the quick response is accessible to.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#is_active ⇒ Boolean
Whether the quick response is active.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#language ⇒ String
The language code value for the language in which the quick response is written. The supported language codes include ‘de_DE`, `en_US`, `es_ES`, `fr_FR`, `id_ID`, `it_IT`, `ja_JP`, `ko_KR`, `pt_BR`, `zh_CN`, `zh_TW`
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response data.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the quick response data was last modified.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#name ⇒ String
The name of the quick response.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#quick_response_id ⇒ String
The identifier of the quick response.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#shortcut_key ⇒ String
The shortcut key of the quick response. The value should be unique across the knowledge base.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#status ⇒ String
The status of the quick response data.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 9093 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9072 class QuickResponseData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :created_time, :last_modified_time, :contents, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :is_active, :channels, :language, :tags) SENSITIVE = [:channels] include Aws::Structure end |