Class: Aws::QConnect::Types::QuickResponseSearchResultData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qconnect/types.rb

Overview

The result of quick response search.

Constant Summary collapse

SENSITIVE =
[:channels, :attributes_not_interpolated, :attributes_interpolated]

Instance Attribute Summary collapse

Instance Attribute Details

#attributes_interpolatedArray<String>

The user defined contact attributes that are resolved when the search result is returned.

Returns:

  • (Array<String>)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#attributes_not_interpolatedArray<String>

The user defined contact attributes that are not resolved when the search result is returned.

Returns:

  • (Array<String>)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#channelsArray<String>

The Amazon Connect contact channels this quick response applies to. The supported contact channel types include ‘Chat`.

Returns:

  • (Array<String>)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#content_typeString

The media type of the quick response content.

  • Use ‘application/x.quickresponse;format=plain` for quick response written in plain text.

  • Use ‘application/x.quickresponse;format=markdown` for quick response written in richtext.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#contentsTypes::QuickResponseContents

The contents of the quick response.



9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#created_timeTime

The timestamp when the quick response was created.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#descriptionString

The description of the quick response.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#grouping_configurationTypes::GroupingConfiguration

The configuration information of the user groups that the quick response is accessible to.



9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#is_activeBoolean

Whether the quick response is active.

Returns:

  • (Boolean)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#knowledge_base_arnString

The Amazon Resource Name (ARN) of the knowledge base.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#knowledge_base_idString

The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#languageString

The language code value for the language in which the quick response is written.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#last_modified_byString

The Amazon Resource Name (ARN) of the user who last updated the quick response search result data.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#last_modified_timeTime

The timestamp when the quick response search result data was last modified.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#nameString

The name of the quick response.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#quick_response_arnString

The Amazon Resource Name (ARN) of the quick response.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#quick_response_idString

The identifier of the quick response.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#shortcut_keyString

The shortcut key of the quick response. The value should be unique across the knowledge base.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#statusString

The resource status of the quick response.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end

#tagsHash<String,String>

The tags used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
# File 'lib/aws-sdk-qconnect/types.rb', line 9394

class QuickResponseSearchResultData < Struct.new(
  :quick_response_arn,
  :quick_response_id,
  :knowledge_base_arn,
  :knowledge_base_id,
  :name,
  :content_type,
  :status,
  :contents,
  :created_time,
  :last_modified_time,
  :is_active,
  :description,
  :grouping_configuration,
  :shortcut_key,
  :last_modified_by,
  :channels,
  :language,
  :attributes_not_interpolated,
  :attributes_interpolated,
  :tags)
  SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated]
  include Aws::Structure
end