Class: Aws::QConnect::Types::QuickResponseSearchResultData
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::QuickResponseSearchResultData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
The result of quick response search.
Constant Summary collapse
- SENSITIVE =
[:channels, :attributes_not_interpolated, :attributes_interpolated]
Instance Attribute Summary collapse
-
#attributes_interpolated ⇒ Array<String>
The user defined contact attributes that are resolved when the search result is returned.
-
#attributes_not_interpolated ⇒ Array<String>
The user defined contact attributes that are not resolved when the search result is returned.
-
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to.
-
#content_type ⇒ String
The media type of the quick response content.
-
#contents ⇒ Types::QuickResponseContents
The contents of the quick response.
-
#created_time ⇒ Time
The timestamp when the quick response was created.
-
#description ⇒ String
The description of the quick response.
-
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the user groups that the quick response is accessible to.
-
#is_active ⇒ Boolean
Whether the quick response is active.
-
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
-
#knowledge_base_id ⇒ String
The identifier of the knowledge base.
-
#language ⇒ String
The language code value for the language in which the quick response is written.
-
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response search result data.
-
#last_modified_time ⇒ Time
The timestamp when the quick response search result data was last modified.
-
#name ⇒ String
The name of the quick response.
-
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
-
#quick_response_id ⇒ String
The identifier of the quick response.
-
#shortcut_key ⇒ String
The shortcut key of the quick response.
-
#status ⇒ String
The resource status of the quick response.
-
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
Instance Attribute Details
#attributes_interpolated ⇒ Array<String>
The user defined contact attributes that are resolved when the search result is returned.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#attributes_not_interpolated ⇒ Array<String>
The user defined contact attributes that are not resolved when the search result is returned.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#channels ⇒ Array<String>
The Amazon Connect contact channels this quick response applies to. The supported contact channel types include ‘Chat`.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#content_type ⇒ String
The media type of the quick response content.
-
Use ‘application/x.quickresponse;format=plain` for quick response written in plain text.
-
Use ‘application/x.quickresponse;format=markdown` for quick response written in richtext.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#contents ⇒ Types::QuickResponseContents
The contents of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#created_time ⇒ Time
The timestamp when the quick response was created.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#description ⇒ String
The description of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#grouping_configuration ⇒ Types::GroupingConfiguration
The configuration information of the user groups that the quick response is accessible to.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#is_active ⇒ Boolean
Whether the quick response is active.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#knowledge_base_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#knowledge_base_id ⇒ String
The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#language ⇒ String
The language code value for the language in which the quick response is written.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#last_modified_by ⇒ String
The Amazon Resource Name (ARN) of the user who last updated the quick response search result data.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#last_modified_time ⇒ Time
The timestamp when the quick response search result data was last modified.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#name ⇒ String
The name of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#quick_response_arn ⇒ String
The Amazon Resource Name (ARN) of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#quick_response_id ⇒ String
The identifier of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#shortcut_key ⇒ String
The shortcut key of the quick response. The value should be unique across the knowledge base.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#status ⇒ String
The resource status of the quick response.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags used to organize, track, or control access for this resource.
9394 9395 9396 9397 9398 9399 9400 9401 9402 9403 9404 9405 9406 9407 9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-qconnect/types.rb', line 9394 class QuickResponseSearchResultData < Struct.new( :quick_response_arn, :quick_response_id, :knowledge_base_arn, :knowledge_base_id, :name, :content_type, :status, :contents, :created_time, :last_modified_time, :is_active, :description, :grouping_configuration, :shortcut_key, :last_modified_by, :channels, :language, :attributes_not_interpolated, :attributes_interpolated, :tags) SENSITIVE = [:channels, :attributes_not_interpolated, :attributes_interpolated] include Aws::Structure end |