Class: Aws::QConnect::Types::SendMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::QConnect::Types::SendMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ai_agent_id ⇒ String
The identifier of the AI Agent to use for processing the message.
-
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#configuration ⇒ Types::MessageConfiguration
The configuration of the [SendMessage] request.
-
#conversation_context ⇒ Types::ConversationContext
The conversation context before the Amazon Q in Connect session.
-
#message ⇒ Types::MessageInput
The message data to submit to the Amazon Q in Connect session.
-
#metadata ⇒ Hash<String,String>
Additional metadata for the message.
-
#orchestrator_use_case ⇒ String
The orchestrator use case for message processing.
-
#origin_request_id ⇒ String
Request identifier from the origin system, used for end-to-end tracing across spans.
-
#session_id ⇒ String
The identifier of the Amazon Q in Connect session.
-
#type ⇒ String
The message type.
Instance Attribute Details
#ai_agent_id ⇒ String
The identifier of the AI Agent to use for processing the message.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#assistant_id ⇒ String
The identifier of the Amazon Q in Connect assistant.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the AWS SDK populates this field.For more information about idempotency, see Making retries safe with idempotent APIs.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::MessageConfiguration
The configuration of the [SendMessage] request.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_amazon-q-connect_SendMessage.html
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#conversation_context ⇒ Types::ConversationContext
The conversation context before the Amazon Q in Connect session.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#message ⇒ Types::MessageInput
The message data to submit to the Amazon Q in Connect session.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
Additional metadata for the message.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#orchestrator_use_case ⇒ String
The orchestrator use case for message processing.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#origin_request_id ⇒ String
Request identifier from the origin system, used for end-to-end tracing across spans.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The identifier of the Amazon Q in Connect session.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The message type.
10467 10468 10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 |
# File 'lib/aws-sdk-qconnect/types.rb', line 10467 class SendMessageRequest < Struct.new( :assistant_id, :session_id, :type, :message, :ai_agent_id, :conversation_context, :configuration, :client_token, :orchestrator_use_case, :metadata, :origin_request_id) SENSITIVE = [] include Aws::Structure end |